@@ -1,10 +1,51 @@
-# u-msgpack-python v1.4 - vsergeev at gmail
+# u-msgpack-python v1.6 - vsergeev at gmail
+# https://github.com/vsergeev/u-msgpack-python
 #
-# u-msgpack-python is a Python 2 and Python 3 compatible serializer and
-# deserializer for msgpack written in pure Python. It supports the latest
-# msgpack spec, as of 09/29/2013, namely the utf-8 string, binary, and ext
+# u-msgpack-python is a lightweight MessagePack serializer and deserializer
+# module, compatible with both Python 2 and 3, as well CPython and PyPy
+# implementations of Python. u-msgpack-python is fully compliant with the
+# latest MessagePack specification.com/msgpack/msgpack/blob/master/spec.md). In
+# particular, it supports the new binary, UTF-8 string, and application ext
 # types.
 #
+# MIT License
+#
+# Copyright (c) 2013-2014 Ivan A. Sergeev
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
+#
+"""
+u-msgpack-python v1.6 - vsergeev at gmail
+https://github.com/vsergeev/u-msgpack-python
+
+u-msgpack-python is a lightweight MessagePack serializer and deserializer
+module, compatible with both Python 2 and 3, as well CPython and PyPy
+implementations of Python. u-msgpack-python is fully compliant with the
+latest MessagePack specification.com/msgpack/msgpack/blob/master/spec.md). In
+particular, it supports the new binary, UTF-8 string, and application ext
+types.
+
+License: MIT
+"""
+
+version = (1,6)
+"Module version tuple"
 
 import struct
 import collections
@@ -12,9 +53,34 @@ import sys
 
 ################################################################################
 
-# Extension type for application code
+# Extension type for application-specific types and data
 class Ext:
+    """
+    The Ext class facilitates creating a serializable extension object to store
+    an application-specific type and data byte array.
+    """
+
     def __init__(self, type, data):
+        """
+        Construct a new Ext object.
+
+        Args:
+            type: application-specific type integer from 0 to 127
+            data: application-specific data byte array
+
+        Raises:
+            TypeError:
+                Specified ext type is outside of 0 to 127 range.
+
+        Example:
+        >>> foo = umsgpack.Ext(0x05, b"\x01\x02\x03")
+        >>> umsgpack.packb({u"special stuff": foo, u"awesome": True})
+        '\x82\xa7awesome\xc3\xadspecial stuff\xc7\x03\x05\x01\x02\x03'
+        >>> bar = umsgpack.unpackb(_)
+        >>> print(bar["special stuff"])
+        Ext Object (Type: 0x05, Data: 01 02 03)
+        >>>
+        """
         # Application ext type should be 0 <= type <= 127
         if not isinstance(type, int) or not (type >= 0 and type <= 127):
             raise TypeError("ext type out of range")
@@ -27,47 +93,101 @@ class Ext:
         self.data = data
 
     def __eq__(self, other):
+        """
+        Compare this Ext object with another for equality.
+        """
         return (isinstance(other, self.__class__) and
                 self.type == other.type and
                 self.data == other.data)
 
     def __ne__(self, other):
+        """
+        Compare this Ext object with another for inequality.
+        """
         return not self.__eq__(other)
 
     def __str__(self):
-        s = "Ext Object\n"
-        s += "   Type: %02x\n" % self.type
-        s += "   Data: "
-        for i in range(len(self.data)):
+        """
+        String representation of this Ext object.
+        """
+        s = "Ext Object (Type: 0x%02x, Data: " % self.type
+        for i in range(min(len(self.data), 8)):
+            if i > 0:
+                s += " "
             if isinstance(self.data[i], int):
-                s += "%02x " % (self.data[i])
+                s += "%02x" % (self.data[i])
             else:
-                s += "%02x " % ord(self.data[i])
-            if i == 16-1:
-                break
-        if len(self.data) > 16:
-            s += "..."
+                s += "%02x" % ord(self.data[i])
+        if len(self.data) > 8:
+            s += " ..."
+        s += ")"
         return s
 
 ################################################################################
 
 # Base Exception classes
-class PackException(Exception): pass
-class UnpackException(Exception): pass
+class PackException(Exception):
+    "Base class for exceptions encountered during packing."
+    pass
+class UnpackException(Exception):
+    "Base class for exceptions encountered during unpacking."
+    pass
 
-# Packing error: Object type not supported for packing.
-class UnsupportedTypeException(PackException): pass
+# Packing error
+class UnsupportedTypeException(PackException):
+    "Object type not supported for packing."
+    pass
 
-# Unpacking error: Insufficient data to unpack encoded object.
-class InsufficientDataException(UnpackException): pass
-# Unpacking error: Invalid string (not UTF-8) encountered.
-class InvalidStringException(UnpackException): pass
-# Unpacking error: Reserved code encountered.
-class ReservedCodeException(UnpackException): pass
-# Unpacking error: Unhashable key encountered during map unpacking.
-class KeyNotPrimitiveException(UnpackException): pass
-# Unpacking error: Duplicate key encountered during map unpacking.
-class KeyDuplicateException(UnpackException): pass
+# Unpacking error
+class InsufficientDataException(UnpackException):
+    "Insufficient data to unpack the encoded object."
+    pass
+class InvalidStringException(UnpackException):
+    "Invalid UTF-8 string encountered during unpacking."
+    pass
+class ReservedCodeException(UnpackException):
+    "Reserved code encountered during unpacking."
+    pass
+class UnhashableKeyException(UnpackException):
+    """
+    Unhashable key encountered during map unpacking.
+    The serialized map cannot be deserialized into a Python dictionary.
+    """
+    pass
+class DuplicateKeyException(UnpackException):
+    "Duplicate key encountered during map unpacking."
+    pass
+
+# Backwards compatibility
+KeyNotPrimitiveException = UnhashableKeyException
+KeyDuplicateException = DuplicateKeyException
+
+################################################################################
+
+# Exported functions and variables set in __init()
+packb = None
+unpackb = None
+dumps = None
+loads = None
+
+compatibility = False
+"""
+Compatibility mode boolean.
+
+When compatibility mode is enabled, u-msgpack-python will serialize both
+unicode strings and bytes into the old "raw" msgpack type, and deserialize the
+"raw" msgpack type into bytes. This provides backwards compatibility with the
+old MessagePack specification.
+
+Example:
+>>> umsgpack.compatibility = True
+>>>
+>>> umsgpack.packb([u"some string", b"some bytes"])
+b'\x92\xabsome string\xaasome bytes'
+>>> umsgpack.unpackb(_)
+[b'some string', b'some bytes']
+>>>
+"""
 
 ################################################################################
 
@@ -76,7 +196,7 @@ class KeyDuplicateException(UnpackException): pass
 # has a str return type instead of bytes in Python 3, and struct.pack(...) has
 # the right return type in both versions.
 
-def pack_integer(x):
+def _pack_integer(x):
     if x < 0:
         if x >= -32:
             return struct.pack("b", x)
@@ -104,31 +224,32 @@ def pack_integer(x):
         else:
             raise UnsupportedTypeException("huge unsigned int")
 
-def pack_nil(x):
+def _pack_nil(x):
     return b"\xc0"
 
-def pack_boolean(x):
+def _pack_boolean(x):
     return b"\xc3" if x else b"\xc2"
 
-def pack_float(x):
+def _pack_float(x):
     if _float_size == 64:
         return b"\xcb" + struct.pack(">d", x)
     else:
         return b"\xca" + struct.pack(">f", x)
 
-def pack_string(x):
+def _pack_string(x):
+    x = x.encode('utf-8')
     if len(x) <= 31:
-        return struct.pack("B", 0xa0 | len(x)) + x.encode('utf-8')
+        return struct.pack("B", 0xa0 | len(x)) + x
     elif len(x) <= 2**8-1:
-        return b"\xd9" + struct.pack("B", len(x)) + x.encode('utf-8')
+        return b"\xd9" + struct.pack("B", len(x)) + x
     elif len(x) <= 2**16-1:
-        return b"\xda" + struct.pack(">H", len(x)) + x.encode('utf-8')
+        return b"\xda" + struct.pack(">H", len(x)) + x
     elif len(x) <= 2**32-1:
-        return b"\xdb" + struct.pack(">I", len(x)) + x.encode('utf-8')
+        return b"\xdb" + struct.pack(">I", len(x)) + x
     else:
         raise UnsupportedTypeException("huge string")
 
-def pack_binary(x):
+def _pack_binary(x):
     if len(x) <= 2**8-1:
         return b"\xc4" + struct.pack("B", len(x)) + x
     elif len(x) <= 2**16-1:
@@ -138,7 +259,7 @@ def pack_binary(x):
     else:
         raise UnsupportedTypeException("huge binary string")
 
-def pack_oldspec_raw(x):
+def _pack_oldspec_raw(x):
     if len(x) <= 31:
         return struct.pack("B", 0xa0 | len(x)) + x
     elif len(x) <= 2**16-1:
@@ -148,7 +269,7 @@ def pack_oldspec_raw(x):
     else:
         raise UnsupportedTypeException("huge raw string")
 
-def pack_ext(x):
+def _pack_ext(x):
     if len(x.data) == 1:
         return b"\xd4" + struct.pack("B", x.type & 0xff) + x.data
     elif len(x.data) == 2:
@@ -168,7 +289,7 @@ def pack_ext(x):
     else:
         raise UnsupportedTypeException("huge ext data")
 
-def pack_array(x):
+def _pack_array(x):
     if len(x) <= 15:
         s = struct.pack("B", 0x90 | len(x))
     elif len(x) <= 2**16-1:
@@ -183,7 +304,7 @@ def pack_array(x):
 
     return s
 
-def pack_map(x):
+def _pack_map(x):
     if len(x) <= 15:
         s = struct.pack("B", 0x80 | len(x))
     elif len(x) <= 2**16-1:
@@ -200,66 +321,102 @@ def pack_map(x):
     return s
 
 # Pack for Python 2, with 'unicode' type, 'str' type, and 'long' type
-def packb2(x):
+def _packb2(x):
+    """
+    Serialize a Python object into MessagePack bytes.
+
+    Args:
+        x: Python object
+
+    Returns:
+        A 'str' containing the serialized bytes.
+
+    Raises:
+        UnsupportedType(PackException):
+            Object type not supported for packing.
+
+    Example:
+    >>> umsgpack.packb({u"compact": True, u"schema": 0})
+    '\x82\xa7compact\xc3\xa6schema\x00'
+    >>>
+    """
     global compatibility
 
     if x is None:
-        return pack_nil(x)
+        return _pack_nil(x)
     elif isinstance(x, bool):
-        return pack_boolean(x)
+        return _pack_boolean(x)
     elif isinstance(x, int) or isinstance(x, long):
-        return pack_integer(x)
+        return _pack_integer(x)
     elif isinstance(x, float):
-        return pack_float(x)
+        return _pack_float(x)
     elif compatibility and isinstance(x, unicode):
-        return pack_oldspec_raw(bytes(x))
+        return _pack_oldspec_raw(bytes(x))
     elif compatibility and isinstance(x, bytes):
-        return pack_oldspec_raw(x)
+        return _pack_oldspec_raw(x)
     elif isinstance(x, unicode):
-        return pack_string(x)
+        return _pack_string(x)
     elif isinstance(x, str):
-        return pack_binary(x)
+        return _pack_binary(x)
     elif isinstance(x, list) or isinstance(x, tuple):
-        return pack_array(x)
+        return _pack_array(x)
     elif isinstance(x, dict):
-        return pack_map(x)
+        return _pack_map(x)
     elif isinstance(x, Ext):
-        return pack_ext(x)
+        return _pack_ext(x)
     else:
         raise UnsupportedTypeException("unsupported type: %s" % str(type(x)))
 
 # Pack for Python 3, with unicode 'str' type, 'bytes' type, and no 'long' type
-def packb3(x):
+def _packb3(x):
+    """
+    Serialize a Python object into MessagePack bytes.
+
+    Args:
+        x: Python object
+
+    Returns:
+        A 'bytes' containing the serialized bytes.
+
+    Raises:
+        UnsupportedType(PackException):
+            Object type not supported for packing.
+
+    Example:
+    >>> umsgpack.packb({u"compact": True, u"schema": 0})
+    b'\x82\xa7compact\xc3\xa6schema\x00'
+    >>>
+    """
     global compatibility
 
     if x is None:
-        return pack_nil(x)
+        return _pack_nil(x)
     elif isinstance(x, bool):
-        return pack_boolean(x)
+        return _pack_boolean(x)
     elif isinstance(x, int):
-        return pack_integer(x)
+        return _pack_integer(x)
     elif isinstance(x, float):
-        return pack_float(x)
+        return _pack_float(x)
     elif compatibility and isinstance(x, str):
-        return pack_oldspec_raw(x.encode('utf-8'))
+        return _pack_oldspec_raw(x.encode('utf-8'))
     elif compatibility and isinstance(x, bytes):
-        return pack_oldspec_raw(x)
+        return _pack_oldspec_raw(x)
     elif isinstance(x, str):
-        return pack_string(x)
+        return _pack_string(x)
     elif isinstance(x, bytes):
-        return pack_binary(x)
+        return _pack_binary(x)
     elif isinstance(x, list) or isinstance(x, tuple):
-        return pack_array(x)
+        return _pack_array(x)
     elif isinstance(x, dict):
-        return pack_map(x)
+        return _pack_map(x)
     elif isinstance(x, Ext):
-        return pack_ext(x)
+        return _pack_ext(x)
     else:
         raise UnsupportedTypeException("unsupported type: %s" % str(type(x)))
 
 ################################################################################
 
-def unpack_integer(code, read_fn):
+def _unpack_integer(code, read_fn):
     if (ord(code) & 0xe0) == 0xe0:
         return struct.unpack("b", code)[0]
     elif code == b'\xd0':
@@ -282,31 +439,31 @@ def unpack_integer(code, read_fn):
         return struct.unpack(">Q", read_fn(8))[0]
     raise Exception("logic error, not int: 0x%02x" % ord(code))
 
-def unpack_reserved(code, read_fn):
+def _unpack_reserved(code, read_fn):
     if code == b'\xc1':
         raise ReservedCodeException("encountered reserved code: 0x%02x" % ord(code))
     raise Exception("logic error, not reserved code: 0x%02x" % ord(code))
 
-def unpack_nil(code, read_fn):
+def _unpack_nil(code, read_fn):
     if code == b'\xc0':
         return None
     raise Exception("logic error, not nil: 0x%02x" % ord(code))
 
-def unpack_boolean(code, read_fn):
+def _unpack_boolean(code, read_fn):
     if code == b'\xc2':
         return False
     elif code == b'\xc3':
         return True
     raise Exception("logic error, not boolean: 0x%02x" % ord(code))
 
-def unpack_float(code, read_fn):
+def _unpack_float(code, read_fn):
     if code == b'\xca':
         return struct.unpack(">f", read_fn(4))[0]
     elif code == b'\xcb':
         return struct.unpack(">d", read_fn(8))[0]
     raise Exception("logic error, not float: 0x%02x" % ord(code))
 
-def unpack_string(code, read_fn):
+def _unpack_string(code, read_fn):
     if (ord(code) & 0xe0) == 0xa0:
         length = ord(code) & ~0xe0
     elif code == b'\xd9':
@@ -328,7 +485,7 @@ def unpack_string(code, read_fn):
     except UnicodeDecodeError:
         raise InvalidStringException("unpacked string is not utf-8")
 
-def unpack_binary(code, read_fn):
+def _unpack_binary(code, read_fn):
     if code == b'\xc4':
         length = struct.unpack("B", read_fn(1))[0]
     elif code == b'\xc5':
@@ -340,7 +497,7 @@ def unpack_binary(code, read_fn):
 
     return read_fn(length)
 
-def unpack_ext(code, read_fn):
+def _unpack_ext(code, read_fn):
     if code == b'\xd4':
         length = 1
     elif code == b'\xd5':
@@ -362,7 +519,7 @@ def unpack_ext(code, read_fn):
 
     return Ext(ord(read_fn(1)), read_fn(length))
 
-def unpack_array(code, read_fn):
+def _unpack_array(code, read_fn):
     if (ord(code) & 0xf0) == 0x90:
         length = (ord(code) & ~0xf0)
     elif code == b'\xdc':
@@ -374,7 +531,7 @@ def unpack_array(code, read_fn):
 
     return [_unpackb(read_fn) for i in range(length)]
 
-def unpack_map(code, read_fn):
+def _unpack_map(code, read_fn):
     if (ord(code) & 0xf0) == 0x80:
         length = (ord(code) & ~0xf0)
     elif code == b'\xde':
@@ -390,9 +547,9 @@ def unpack_map(code, read_fn):
         k = _unpackb(read_fn)
 
         if not isinstance(k, collections.Hashable):
-            raise KeyNotPrimitiveException("encountered non-primitive key type: %s" % str(type(k)))
+            raise UnhashableKeyException("encountered unhashable key type: %s" % str(type(k)))
         elif k in d:
-            raise KeyDuplicateException("encountered duplicate key: %s, %s" % (str(k), str(type(k))))
+            raise DuplicateKeyException("encountered duplicate key: %s, %s" % (str(k), str(type(k))))
 
         # Unpack value
         v = _unpackb(read_fn)
@@ -402,7 +559,7 @@ def unpack_map(code, read_fn):
 
 ########################################
 
-def byte_reader(s):
+def _byte_reader(s):
     i = [0]
     def read_fn(n):
         if (i[0]+n > len(s)):
@@ -417,27 +574,87 @@ def _unpackb(read_fn):
     return _unpack_dispatch_table[code](code, read_fn)
 
 # For Python 2, expects a str object
-def unpackb2(s):
+def _unpackb2(s):
+    """
+    Deserialize MessagePack bytes into a Python object.
+
+    Args:
+        s: a 'str' containing the MessagePack serialized bytes.
+
+    Returns:
+        A deserialized Python object.
+
+    Raises:
+        TypeError:
+            Packed data is not type 'str'.
+        InsufficientDataException(UnpackException):
+            Insufficient data to unpack the encoded object.
+        InvalidStringException(UnpackException):
+            Invalid UTF-8 string encountered during unpacking.
+        ReservedCodeException(UnpackException):
+            Reserved code encountered during unpacking.
+        UnhashableKeyException(UnpackException):
+            Unhashable key encountered during map unpacking.
+            The serialized map cannot be deserialized into a Python dictionary.
+        DuplicateKeyException(UnpackException):
+            Duplicate key encountered during map unpacking.
+
+    Example:
+    >>> umsgpack.unpackb(b'\x82\xa7compact\xc3\xa6schema\x00')
+    {u'compact': True, u'schema': 0}
+    >>>
+    """
     if not isinstance(s, str):
         raise TypeError("packed data is not type 'str'")
-    read_fn = byte_reader(s)
+    read_fn = _byte_reader(s)
     return _unpackb(read_fn)
 
 # For Python 3, expects a bytes object
-def unpackb3(s):
+def _unpackb3(s):
+    """
+    Deserialize MessagePack bytes into a Python object.
+
+    Args:
+        s: a 'bytes' containing the MessagePack serialized bytes.
+
+    Returns:
+        A deserialized Python object.
+
+    Raises:
+        TypeError:
+            Packed data is not type 'bytes'.
+        InsufficientDataException(UnpackException):
+            Insufficient data to unpack the encoded object.
+        InvalidStringException(UnpackException):
+            Invalid UTF-8 string encountered during unpacking.
+        ReservedCodeException(UnpackException):
+            Reserved code encountered during unpacking.
+        UnhashableKeyException(UnpackException):
+            Unhashable key encountered during map unpacking.
+            The serialized map cannot be deserialized into a Python dictionary.
+        DuplicateKeyException(UnpackException):
+            Duplicate key encountered during map unpacking.
+
+    Example:
+    >>> umsgpack.unpackb(b'\x82\xa7compact\xc3\xa6schema\x00')
+    {'compact': True, 'schema': 0}
+    >>>
+    """
     if not isinstance(s, bytes):
         raise TypeError("packed data is not type 'bytes'")
-    read_fn = byte_reader(s)
+    read_fn = _byte_reader(s)
     return _unpackb(read_fn)
 
 ################################################################################
 
 def __init():
-    global _float_size
     global packb
     global unpackb
-    global _unpack_dispatch_table
+    global dumps
+    global loads
     global compatibility
+    global _float_size
+    global _unpack_dispatch_table
 
     # Compatibility mode for handling strings/bytes with the old specification
     compatibility = False
@@ -450,63 +667,67 @@ def __init():
 
     # Map packb and unpackb to the appropriate version
     if sys.version_info[0] == 3:
-        packb = packb3
-        unpackb = unpackb3
+        packb = _packb3
+        dumps = _packb3
+        unpackb = _unpackb3
+        loads = _unpackb3
     else:
-        packb = packb2
-        unpackb = unpackb2
+        packb = _packb2
+        dumps = _packb2
+        unpackb = _unpackb2
+        loads = _unpackb2
 
     # Build a dispatch table for fast lookup of unpacking function
 
     _unpack_dispatch_table = {}
     # Fix uint
     for code in range(0, 0x7f+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_integer
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_integer
     # Fix map
     for code in range(0x80, 0x8f+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_map
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_map
     # Fix array
     for code in range(0x90, 0x9f+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_array
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_array
     # Fix str
     for code in range(0xa0, 0xbf+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_string
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_string
     # Nil
-    _unpack_dispatch_table[b'\xc0'] = unpack_nil
+    _unpack_dispatch_table[b'\xc0'] = _unpack_nil
     # Reserved
-    _unpack_dispatch_table[b'\xc1'] = unpack_reserved
+    _unpack_dispatch_table[b'\xc1'] = _unpack_reserved
     # Boolean
-    _unpack_dispatch_table[b'\xc2'] = unpack_boolean
-    _unpack_dispatch_table[b'\xc3'] = unpack_boolean
+    _unpack_dispatch_table[b'\xc2'] = _unpack_boolean
+    _unpack_dispatch_table[b'\xc3'] = _unpack_boolean
     # Bin
     for code in range(0xc4, 0xc6+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_binary
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_binary
     # Ext
     for code in range(0xc7, 0xc9+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_ext
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_ext
     # Float
-    _unpack_dispatch_table[b'\xca'] = unpack_float
-    _unpack_dispatch_table[b'\xcb'] = unpack_float
+    _unpack_dispatch_table[b'\xca'] = _unpack_float
+    _unpack_dispatch_table[b'\xcb'] = _unpack_float
     # Uint
     for code in range(0xcc, 0xcf+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_integer
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_integer
     # Int
     for code in range(0xd0, 0xd3+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_integer
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_integer
     # Fixext
     for code in range(0xd4, 0xd8+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_ext
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_ext
     # String
     for code in range(0xd9, 0xdb+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_string
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_string
     # Array
-    _unpack_dispatch_table[b'\xdc'] = unpack_array
-    _unpack_dispatch_table[b'\xdd'] = unpack_array
+    _unpack_dispatch_table[b'\xdc'] = _unpack_array
+    _unpack_dispatch_table[b'\xdd'] = _unpack_array
     # Map
-    _unpack_dispatch_table[b'\xde'] = unpack_map
-    _unpack_dispatch_table[b'\xdf'] = unpack_map
+    _unpack_dispatch_table[b'\xde'] = _unpack_map
+    _unpack_dispatch_table[b'\xdf'] = _unpack_map
     # Negative fixint
     for code in range(0xe0, 0xff+1):
-        _unpack_dispatch_table[struct.pack("B", code)] = unpack_integer
+        _unpack_dispatch_table[struct.pack("B", code)] = _unpack_integer
 
 __init()
